==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OktaIpChangeEvent.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CaepDeviceComplianceChangeEventReasonAdmin;
import com.okta.sdk.resource.model.CaepDeviceComplianceChangeEventReasonUser;
import com.okta.sdk.resource.model.SecurityEventSubject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IP changed for the subject&#39;s session
 */
@ApiModel(description = "IP changed for the subject's session")
@JsonPropertyOrder({ OktaIpChangeEvent.JSON_PROPERTY_CURRENT_IP_ADDRESS,
        OktaIpChangeEvent.JSON_PROPERTY_EVENT_TIMESTAMP, OktaIpChangeEvent.JSON_PROPERTY_INITIATING_ENTITY,
        OktaIpChangeEvent.JSON_PROPERTY_PREVIOUS_IP_ADDRESS, OktaIpChangeEvent.JSON_PROPERTY_REASON_ADMIN,
        OktaIpChangeEvent.JSON_PROPERTY_REASON_USER, OktaIpChangeEvent.JSON_PROPERTY_SUBJECT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class OktaIpChangeEvent implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CURRENT_IP_ADDRESS = "current_ip_address";
    private String currentIpAddress;

    public static final String JSON_PROPERTY_EVENT_TIMESTAMP = "event_timestamp";
    private Long eventTimestamp;

    /**
     * The entity that initiated the event
     */
    public enum InitiatingEntityEnum {
        ADMIN(String.valueOf("admin")),

        USER(String.valueOf("user")),

        POLICY(String.valueOf("policy")),

        SYSTEM(String.valueOf("system")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        InitiatingEntityEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static InitiatingEntityEnum fromValue(String value) {
            for (InitiatingEntityEnum b : InitiatingEntityEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_INITIATING_ENTITY = "initiating_entity";
    private InitiatingEntityEnum initiatingEntity;

    public static final String JSON_PROPERTY_PREVIOUS_IP_ADDRESS = "previous_ip_address";
    private String previousIpAddress;

    public static final String JSON_PROPERTY_REASON_ADMIN = "reason_admin";
    private CaepDeviceComplianceChangeEventReasonAdmin reasonAdmin;

    public static final String JSON_PROPERTY_REASON_USER = "reason_user";
    private CaepDeviceComplianceChangeEventReasonUser reasonUser;

    public static final String JSON_PROPERTY_SUBJECT = "subject";
    private SecurityEventSubject subject;

    public OktaIpChangeEvent() {
    }

    public OktaIpChangeEvent currentIpAddress(String currentIpAddress) {

        this.currentIpAddress = currentIpAddress;
        return this;
    }

    /**
     * Current IP address of the subject
     *
     * @return currentIpAddress
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "123.4.5.6", required = true, value = "Current IP address of the subject")
    @JsonProperty(JSON_PROPERTY_CURRENT_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getCurrentIpAddress() {
        return currentIpAddress;
    }

    @JsonProperty(JSON_PROPERTY_CURRENT_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setCurrentIpAddress(String currentIpAddress) {
        this.currentIpAddress = currentIpAddress;
    }

    public OktaIpChangeEvent eventTimestamp(Long eventTimestamp) {

        this.eventTimestamp = eventTimestamp;
        return this;
    }

    /**
     * The time of the event (UNIX timestamp)
     *
     * @return eventTimestamp
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "1702448550", required = true, value = "The time of the event (UNIX timestamp)")
    @JsonProperty(JSON_PROPERTY_EVENT_TIMESTAMP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public Long getEventTimestamp() {
        return eventTimestamp;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TIMESTAMP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setEventTimestamp(Long eventTimestamp) {
        this.eventTimestamp = eventTimestamp;
    }

    public OktaIpChangeEvent initiatingEntity(InitiatingEntityEnum initiatingEntity) {

        this.initiatingEntity = initiatingEntity;
        return this;
    }

    /**
     * The entity that initiated the event
     *
     * @return initiatingEntity
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The entity that initiated the event")
    @JsonProperty(JSON_PROPERTY_INITIATING_ENTITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InitiatingEntityEnum getInitiatingEntity() {
        return initiatingEntity;
    }

    @JsonProperty(JSON_PROPERTY_INITIATING_ENTITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInitiatingEntity(InitiatingEntityEnum initiatingEntity) {
        this.initiatingEntity = initiatingEntity;
    }

    public OktaIpChangeEvent previousIpAddress(String previousIpAddress) {

        this.previousIpAddress = previousIpAddress;
        return this;
    }

    /**
     * Previous IP address of the subject
     *
     * @return previousIpAddress
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "123.45.67.8", required = true, value = "Previous IP address of the subject")
    @JsonProperty(JSON_PROPERTY_PREVIOUS_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getPreviousIpAddress() {
        return previousIpAddress;
    }

    @JsonProperty(JSON_PROPERTY_PREVIOUS_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setPreviousIpAddress(String previousIpAddress) {
        this.previousIpAddress = previousIpAddress;
    }

    public OktaIpChangeEvent reasonAdmin(CaepDeviceComplianceChangeEventReasonAdmin reasonAdmin) {

        this.reasonAdmin = reasonAdmin;
        return this;
    }

    /**
     * Get reasonAdmin
     *
     * @return reasonAdmin
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REASON_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CaepDeviceComplianceChangeEventReasonAdmin getReasonAdmin() {
        return reasonAdmin;
    }

    @JsonProperty(JSON_PROPERTY_REASON_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setReasonAdmin(CaepDeviceComplianceChangeEventReasonAdmin reasonAdmin) {
        this.reasonAdmin = reasonAdmin;
    }

    public OktaIpChangeEvent reasonUser(CaepDeviceComplianceChangeEventReasonUser reasonUser) {

        this.reasonUser = reasonUser;
        return this;
    }

    /**
     * Get reasonUser
     *
     * @return reasonUser
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REASON_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CaepDeviceComplianceChangeEventReasonUser getReasonUser() {
        return reasonUser;
    }

    @JsonProperty(JSON_PROPERTY_REASON_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setReasonUser(CaepDeviceComplianceChangeEventReasonUser reasonUser) {
        this.reasonUser = reasonUser;
    }

    public OktaIpChangeEvent subject(SecurityEventSubject subject) {

        this.subject = subject;
        return this;
    }

    /**
     * Get subject
     *
     * @return subject
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public SecurityEventSubject getSubject() {
        return subject;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setSubject(SecurityEventSubject subject) {
        this.subject = subject;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OktaIpChangeEvent oktaIpChangeEvent = (OktaIpChangeEvent) o;
        return Objects.equals(this.currentIpAddress, oktaIpChangeEvent.currentIpAddress)
                && Objects.equals(this.eventTimestamp, oktaIpChangeEvent.eventTimestamp)
                && Objects.equals(this.initiatingEntity, oktaIpChangeEvent.initiatingEntity)
                && Objects.equals(this.previousIpAddress, oktaIpChangeEvent.previousIpAddress)
                && Objects.equals(this.reasonAdmin, oktaIpChangeEvent.reasonAdmin)
                && Objects.equals(this.reasonUser, oktaIpChangeEvent.reasonUser)
                && Objects.equals(this.subject, oktaIpChangeEvent.subject);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(currentIpAddress, eventTimestamp, initiatingEntity, previousIpAddress, reasonAdmin,
                reasonUser, subject);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OktaIpChangeEvent {\n");
        sb.append("    currentIpAddress: ").append(toIndentedString(currentIpAddress)).append("\n");
        sb.append("    eventTimestamp: ").append(toIndentedString(eventTimestamp)).append("\n");
        sb.append("    initiatingEntity: ").append(toIndentedString(initiatingEntity)).append("\n");
        sb.append("    previousIpAddress: ").append(toIndentedString(previousIpAddress)).append("\n");
        sb.append("    reasonAdmin: ").append(toIndentedString(reasonAdmin)).append("\n");
        sb.append("    reasonUser: ").append(toIndentedString(reasonUser)).append("\n");
        sb.append("    subject: ").append(toIndentedString(subject)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OktaIpChangeEvent.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CaepDeviceComplianceChangeEventReasonAdmin;
import com.okta.sdk.resource.model.CaepDeviceComplianceChangeEventReasonUser;
import com.okta.sdk.resource.model.SecurityEventSubject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IP changed for the subject&#39;s session
 */
@ApiModel(description = "IP changed for the subject's session")
@JsonPropertyOrder({ OktaIpChangeEvent.JSON_PROPERTY_CURRENT_IP_ADDRESS,
        OktaIpChangeEvent.JSON_PROPERTY_EVENT_TIMESTAMP, OktaIpChangeEvent.JSON_PROPERTY_INITIATING_ENTITY,
        OktaIpChangeEvent.JSON_PROPERTY_PREVIOUS_IP_ADDRESS, OktaIpChangeEvent.JSON_PROPERTY_REASON_ADMIN,
        OktaIpChangeEvent.JSON_PROPERTY_REASON_USER, OktaIpChangeEvent.JSON_PROPERTY_SUBJECT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class OktaIpChangeEvent implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CURRENT_IP_ADDRESS = "current_ip_address";
    private String currentIpAddress;

    public static final String JSON_PROPERTY_EVENT_TIMESTAMP = "event_timestamp";
    private Long eventTimestamp;

    /**
     * The entity that initiated the event
     */
    public enum InitiatingEntityEnum {
        ADMIN(String.valueOf("admin")),

        USER(String.valueOf("user")),

        POLICY(String.valueOf("policy")),

        SYSTEM(String.valueOf("system")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        InitiatingEntityEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static InitiatingEntityEnum fromValue(String value) {
            for (InitiatingEntityEnum b : InitiatingEntityEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_INITIATING_ENTITY = "initiating_entity";
    private InitiatingEntityEnum initiatingEntity;

    public static final String JSON_PROPERTY_PREVIOUS_IP_ADDRESS = "previous_ip_address";
    private String previousIpAddress;

    public static final String JSON_PROPERTY_REASON_ADMIN = "reason_admin";
    private CaepDeviceComplianceChangeEventReasonAdmin reasonAdmin;

    public static final String JSON_PROPERTY_REASON_USER = "reason_user";
    private CaepDeviceComplianceChangeEventReasonUser reasonUser;

    public static final String JSON_PROPERTY_SUBJECT = "subject";
    private SecurityEventSubject subject;

    public OktaIpChangeEvent() {
    }

    public OktaIpChangeEvent currentIpAddress(String currentIpAddress) {

        this.currentIpAddress = currentIpAddress;
        return this;
    }

    /**
     * Current IP address of the subject
     *
     * @return currentIpAddress
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "123.4.5.6", required = true, value = "Current IP address of the subject")
    @JsonProperty(JSON_PROPERTY_CURRENT_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getCurrentIpAddress() {
        return currentIpAddress;
    }

    @JsonProperty(JSON_PROPERTY_CURRENT_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setCurrentIpAddress(String currentIpAddress) {
        this.currentIpAddress = currentIpAddress;
    }

    public OktaIpChangeEvent eventTimestamp(Long eventTimestamp) {

        this.eventTimestamp = eventTimestamp;
        return this;
    }

    /**
     * The time of the event (UNIX timestamp)
     *
     * @return eventTimestamp
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "1702448550", required = true, value = "The time of the event (UNIX timestamp)")
    @JsonProperty(JSON_PROPERTY_EVENT_TIMESTAMP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public Long getEventTimestamp() {
        return eventTimestamp;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TIMESTAMP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setEventTimestamp(Long eventTimestamp) {
        this.eventTimestamp = eventTimestamp;
    }

    public OktaIpChangeEvent initiatingEntity(InitiatingEntityEnum initiatingEntity) {

        this.initiatingEntity = initiatingEntity;
        return this;
    }

    /**
     * The entity that initiated the event
     *
     * @return initiatingEntity
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The entity that initiated the event")
    @JsonProperty(JSON_PROPERTY_INITIATING_ENTITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InitiatingEntityEnum getInitiatingEntity() {
        return initiatingEntity;
    }

    @JsonProperty(JSON_PROPERTY_INITIATING_ENTITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInitiatingEntity(InitiatingEntityEnum initiatingEntity) {
        this.initiatingEntity = initiatingEntity;
    }

    public OktaIpChangeEvent previousIpAddress(String previousIpAddress) {

        this.previousIpAddress = previousIpAddress;
        return this;
    }

    /**
     * Previous IP address of the subject
     *
     * @return previousIpAddress
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "123.45.67.8", required = true, value = "Previous IP address of the subject")
    @JsonProperty(JSON_PROPERTY_PREVIOUS_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getPreviousIpAddress() {
        return previousIpAddress;
    }

    @JsonProperty(JSON_PROPERTY_PREVIOUS_IP_ADDRESS)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setPreviousIpAddress(String previousIpAddress) {
        this.previousIpAddress = previousIpAddress;
    }

    public OktaIpChangeEvent reasonAdmin(CaepDeviceComplianceChangeEventReasonAdmin reasonAdmin) {

        this.reasonAdmin = reasonAdmin;
        return this;
    }

    /**
     * Get reasonAdmin
     *
     * @return reasonAdmin
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REASON_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CaepDeviceComplianceChangeEventReasonAdmin getReasonAdmin() {
        return reasonAdmin;
    }

    @JsonProperty(JSON_PROPERTY_REASON_ADMIN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setReasonAdmin(CaepDeviceComplianceChangeEventReasonAdmin reasonAdmin) {
        this.reasonAdmin = reasonAdmin;
    }

    public OktaIpChangeEvent reasonUser(CaepDeviceComplianceChangeEventReasonUser reasonUser) {

        this.reasonUser = reasonUser;
        return this;
    }

    /**
     * Get reasonUser
     *
     * @return reasonUser
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REASON_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CaepDeviceComplianceChangeEventReasonUser getReasonUser() {
        return reasonUser;
    }

    @JsonProperty(JSON_PROPERTY_REASON_USER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setReasonUser(CaepDeviceComplianceChangeEventReasonUser reasonUser) {
        this.reasonUser = reasonUser;
    }

    public OktaIpChangeEvent subject(SecurityEventSubject subject) {

        this.subject = subject;
        return this;
    }

    /**
     * Get subject
     *
     * @return subject
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public SecurityEventSubject getSubject() {
        return subject;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setSubject(SecurityEventSubject subject) {
        this.subject = subject;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OktaIpChangeEvent oktaIpChangeEvent = (OktaIpChangeEvent) o;
        return Objects.equals(this.currentIpAddress, oktaIpChangeEvent.currentIpAddress)
                && Objects.equals(this.eventTimestamp, oktaIpChangeEvent.eventTimestamp)
                && Objects.equals(this.initiatingEntity, oktaIpChangeEvent.initiatingEntity)
                && Objects.equals(this.previousIpAddress, oktaIpChangeEvent.previousIpAddress)
                && Objects.equals(this.reasonAdmin, oktaIpChangeEvent.reasonAdmin)
                && Objects.equals(this.reasonUser, oktaIpChangeEvent.reasonUser)
                && Objects.equals(this.subject, oktaIpChangeEvent.subject);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(currentIpAddress, eventTimestamp, initiatingEntity, previousIpAddress, reasonAdmin,
                reasonUser, subject);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OktaIpChangeEvent {\n");
        sb.append("    currentIpAddress: ").append(toIndentedString(currentIpAddress)).append("\n");
        sb.append("    eventTimestamp: ").append(toIndentedString(eventTimestamp)).append("\n");
        sb.append("    initiatingEntity: ").append(toIndentedString(initiatingEntity)).append("\n");
        sb.append("    previousIpAddress: ").append(toIndentedString(previousIpAddress)).append("\n");
        sb.append("    reasonAdmin: ").append(toIndentedString(reasonAdmin)).append("\n");
        sb.append("    reasonUser: ").append(toIndentedString(reasonUser)).append("\n");
        sb.append("    subject: ").append(toIndentedString(subject)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
